// Dialog procedure for the notebook control

#define INCL_DOS
#define INCL_WIN
#define INCL_PM

#include <string.h>
#include <stdlib.h>
#include <os2.h>

#include "Basic.hpp"
#include "Resource.h"
#include "Class_Notebook.hpp"

//------------------------------------------------------------------------
// Global variables

struct wdDlg_Notebook {
     Class_Notebook *Notebook;// Notebook
     ULONG ulPageID;// ID of currently displayed window
};

wdDlg_Notebook *wd;

//------------------------------------------------------------------------
//Function prototypes

MRESULT EXPENTRY Dlg_NbkpPage ( HWND hwnd, ULONG msg, MPARAM mp1, MPARAM mp2 );

//------------------------------------------------------------------------

MRESULT EXPENTRY Dlg_Notebook( HWND hwnd, ULONG msg, MPARAM mp1, MPARAM mp2 )
{
     wd = (wdDlg_Notebook *) WinQueryWindowPtr( hwnd, 0 );

     switch( msg )
     {
     //----------------------------------
     case WM_INITDLG:
     {
          wd = new wdDlg_Notebook;
          if( !wd )
          {
               ErrorBox( "Error creating a window word in WM_INITDLG of Dlg_Notebook" );
               WinDestroyWindow( hwnd );
               exit( 1 );
          }
          if( !WinSetWindowPtr( hwnd, 0, wd ) )
          {
               ErrorBox( "Error setting window word 0  in WM_INITDLG of Dlg_Notebook" );
               WinDestroyWindow( hwnd );
               exit( 1 );
          }

          // There currently is no notebook page selected
          // This initialization is required so that a validation will not
          // be performed on the first notebook page while it is being
          // created
          wd->ulPageID = NULL;

          // Create an instance of the notebook
          wd->Notebook = new Class_Notebook( hwnd, NBK_NOTEBOOK );

          // Add a major notebook tab
          wd->Notebook->AddMajor( NBKP_NOTEBOOK1,
                                  "First Major Page",
                                  Dlg_NbkpPage,
                                  "Status Text 1" );

          // Add a minor notebook
          wd->Notebook->AddMinor( NBKP_NOTEBOOK2,
                                  "Special Text For Minor Tab Of First Major Page",
                                  Dlg_NbkpPage,
                                  "Status Text 2" );

          // Add a major notebook tab
          wd->Notebook->AddMajor( NBKP_NOTEBOOK3,
                                  "Second Major Page",
                                  Dlg_NbkpPage,
                                  "Status Text 3" );

          // Give the focus to the notebook dialog, so that the titlebar
          // is of the appropriate color i.e. that of a selected window
          WinSetFocus( HWND_DESKTOP, WinQueryWindow( hwnd, QW_PARENT ) );
     }
     break;
     //----------------------------------
     case WM_CLOSE:
     {
          // Validate the current notebook page
          if( !wd->Notebook->SendMessage( wd->ulPageID, WM_VALIDATE, 0, 0 ) )
          {
               // Validation error on the current notebook page
               DosBeep( 1440, 100 );// Warn the user that something is going on
               return 0;
          }

          // Send a WM_CLOSE to all the notebook pages
          wd->Notebook->SendMessage( 0, WM_CLOSE, 0, 0 );

          // Release dynamic memory
          delete wd->Notebook;
          delete wd;

          // Close the notebook dialog (main dialog window)
          WinPostMsg( hwnd, WM_QUIT, 0, 0 );
     }
     break;
     //----------------------------------
     case WM_COMMAND:
          switch( SHORT1FROMMP( mp1 ) )
          {
                case DID_CANCEL:
                     // Prevent ESC from closing the dialog
                     return 0;
                //----------------------------------
               case PB_UNDO:
                    // Send a message to the currently displayed notebook page
                    // The message is simply that the PB_UNDO pushbutton has
                    // been pressed
                    wd->Notebook->SendMessage( wd->ulPageID, WM_COMMAND, MPARAM( PB_UNDO ), 0 );
                    break;
                //----------------------------------
               case PB_DEFAULT:
                    // Post a message to the currently displayed notebook page
                    // The message is simply that the PB_DEFAULT pushbutton has
                    // been pressed
                    wd->Notebook->PostMessage( wd->ulPageID, WM_COMMAND, MPARAM( PB_DEFAULT ), 0 );
                    break;
          }
     //----------------------------------
     case WM_CONTROL:
          switch( SHORT1FROMMP( mp1 ) )
          {
          case NBK_NOTEBOOK:
               switch( SHORT2FROMMP( mp1 ) )
               {
               case BKN_PAGESELECTED:
                    // Keep track of the ID of the currently displayed notebook page
                    wd->ulPageID = ( (PPAGESELECTNOTIFY) mp2 )->ulPageIdNew;
               break;
                //----------------------------------
               case BKN_HELP:
                    // The notebook control received a WM_HELP message
               break;
                //----------------------------------
               case BKN_PAGESELECTEDPENDING:
                    // The current page is about to be changed
                    // This would be an appropriate time to perform validations
                    // of the controls on that page

                    // Do not perform validation when creating the notebook control
                    // i.e. when going to the initial notebook page
                    if( wd->ulPageID && !wd->Notebook->SendMessage( wd->ulPageID, WM_VALIDATE, 0, 0 ) )
                    {
                         // Validation error on the current notebook page
                         // Prevent the change of page
                         ( (PPAGESELECTNOTIFY) mp2 )->ulPageIdNew = NULL;
                          DosBeep( 1440, 100 );// Warn the user that something is going on
                    }
               break;
               }
          }
     //----------------------------------
     case WM_VERIFYSHUTDOWN:
          // It's ok to close the notebook
          return MPARAM( TRUE );
     //----------------------------------

     }//switch( msg )

     return WinDefDlgProc( hwnd, msg, mp1, mp2 );

}// Dlg_Notebook Dialog Procedure

